@@ -94,6 +94,9 @@ class Controller:
             if pic is not None:
                 self.__viewer.reset_name_tm(pic, self.paused, side, self.__model.get_current_pics()[1] is not None)
 
+    def purge_files(self):
+        self.__model.purge_files()
+
     @property
     def subdirectory(self):
         return self.__model.subdirectory
@@ -113,7 +116,7 @@ class Controller:
         try:
             self.__date_from = float(val)
         except ValueError:
-            self.__date_from = make_date(val if len(val) > 0 else '1970/1/1')
+            self.__date_from = make_date(val if len(val) > 0 else '1901/12/15')
         if len(val) > 0:
             self.__model.set_where_clause('date_from', "exif_datetime > {:.0f}".format(self.__date_from))
         else:
@@ -194,26 +197,50 @@ class Controller:
     def location_filter(self, val):
         self.__location_filter = val
         if len(val) > 0:
-            self.__model.set_where_clause('location_filter', "location LIKE '%{}%'".format(val))
+            self.__model.set_where_clause("location_filter", self.__build_filter(val, "location"))
         else:
-            self.__model.set_where_clause('location_filter') # remove from where_clause
+            self.__model.set_where_clause("location_filter") # remove from where_clause
         self.__model.force_reload()
         self.__next_tm = 0
 
     @property
     def tags_filter(self):
         return self.__tags_filter
-    
+
     @tags_filter.setter
     def tags_filter(self, val):
         self.__tags_filter = val
         if len(val) > 0:
-            self.__model.set_where_clause('tags_filter', "tags LIKE '%{}%'".format(val))
+            self.__model.set_where_clause("tags_filter", self.__build_filter(val, "tags"))
         else:
-            self.__model.set_where_clause('tags_filter') # remove from where_clause
+            self.__model.set_where_clause("tags_filter") # remove from where_clause
         self.__model.force_reload()
         self.__next_tm = 0
 
+    def __build_filter(self, val, field):
+        if val.count("(") != val.count(")"):
+            return None # this should clear the filter and not raise an error
+        val = val.replace(";", "").replace("'", "").replace("%", "").replace('"', '') # SQL scrambling
+        tokens = ("(", ")", "AND", "OR", "NOT") # now copes with NOT
+        val_split = val.replace("(", " ( ").replace(")", " ) ").split() # so brackets not joined to words
+        filter = []
+        last_token = ""
+        for s in val_split:
+            s_upper = s.upper()
+            if s_upper in tokens:
+                if s_upper in ("AND", "OR"):
+                    if last_token in ("AND", "OR"):
+                        return None # must have a non-token between
+                    last_token = s_upper
+                filter.append(s)
+            else:
+                if last_token is not None:
+                    filter.append("{} LIKE '%{}%'".format(field, s))
+                else:
+                    filter[-1] = filter[-1].replace("%'", " {}%'".format(s))
+                last_token = None
+        return "({})".format(" ".join(filter)) # if OR outside brackets will modify the logic of rest of where clauses
+
     def text_is_on(self, txt_key):
         return self.__viewer.text_is_on(txt_key)
 
